@@ -1,6 +1,10 @@
 /*
 **  Transmit articles to remote site.
+**  Originally written by Rich $alz.
 **  Modified for NNTP streaming: 1996-01-03 Jerry Aguirre.
+**
+**  Various bug fixes, code and documentation improvements since then
+**  in 1997-2007, 2009-2011, 2014, 2015, 2017, 2021, 2022, 2024.
 */
 
 #include "portable/system.h"
@@ -83,7 +87,7 @@
 **     0 <= stnq <= STNBUF
 **     0 <= stoldest < STNBUF
 */
-struct stbufs {                      /* for each article we are procesing */
+struct stbufs {                      /* for each article we are processing */
     char st_fname[SPOOLNAMEBUFF];    /* file name */
     char st_id[NNTP_MAXLEN_COMMAND]; /* Message-ID */
     unsigned int st_retry;           /* retry count (0 for the first try) */
@@ -96,8 +100,8 @@ static int stnq;      /* current number of active entries in stbuf */
 static long stnofail; /* Count of consecutive successful sends */
 static int stoldest;  /* Oldest allocated entry to stbuf (if stnq!=0) */
 
-static int TryStream = true;  /* Should attempt stream negotation? */
-static int CanStream = false; /* Result of stream negotation */
+static int TryStream = true;  /* Should attempt stream negotiation? */
+static int CanStream = false; /* Result of stream negotiation */
 static int DoCheck = true;    /* Should check before takethis? */
 static char modestream[] = "MODE STREAM";
 static char modeheadfeed[] = "MODE HEADFEED";
