@@ -5,6 +5,9 @@
  *
  * This program uses expire.ctl.ctl as input; please see the end of this
  * file for an example of such a file.
+ *
+ * Various bug fixes, code and documentation improvements
+ * in 2001, 2011, 2014, 2015, 2021, 2024.
  */
 
 /*
@@ -159,7 +162,7 @@ main(int ac, char **av)
         if ((fi = fopen(EXPIRE_DAYS, "r")) != NULL) {
             while (fgets(buf, sizeof(buf), fi) != NULL) {
                 if (strncmp(buf, "time", 4) == 0) {
-                    expireIncTime = strtol(buf + 4, NULL, 0);
+                    expireIncTime = strtoul(buf + 4, NULL, 0);
                 } else if (strncmp(buf, "days", 4) == 0) {
                     expireDays = strtol(buf + 4, NULL, 0);
                 }
