@@ -435,7 +435,7 @@ ARTheaderpcmp(const void *p1, const void *p2)
 /* Write an article using the storage api.  Put it together in memory and
    call out to the api. */
 static TOKEN
-ARTstore(CHANNEL *cp)
+ARTstore(CHANNEL *cp, bool filtered)
 {
     struct buffer *Article = &cp->In;
     ARTDATA *data = &cp->Data;
@@ -557,6 +557,7 @@ ARTstore(CHANNEL *cp)
     arth.arrived = (time_t) 0;
     arth.token = (TOKEN *) NULL;
     arth.expires = data->Expires;
+    arth.filtered = filtered;
     if (innconf->storeonxref) {
         arth.groups = data->Replic;
         arth.groupslen = data->ReplicLength;
@@ -564,6 +565,8 @@ ARTstore(CHANNEL *cp)
         arth.groups = HDR(HDR__NEWSGROUPS);
         arth.groupslen = HDR_LEN(HDR__NEWSGROUPS);
     }
+    arth.path = HDR(HDR__PATH);
+    arth.pathlen = HDR_LEN(HDR__PATH);
 
     SMerrno = SMERR_NOERROR;
     result = SMstore(arth);
@@ -726,7 +729,7 @@ ARTcheckheader(CHANNEL *cp, int size)
 
 
 /*
-**  Clean up data field where article informations are stored.
+**  Clean up data field where article information are stored.
 **  This must be called before article processing.
 */
 void
@@ -1694,7 +1697,7 @@ HashFeedMatch(HASHFEEDLIST *hf, char *MessageID)
 */
 static void
 ARTpropagate(ARTDATA *data, const char **hops, int hopcount, char **list,
-             bool ControlStore, bool OverviewCreated, bool Filtered)
+             bool ControlStore, bool OverviewCreated, bool filtered)
 {
     HDRCONTENT *hc = data->HdrContent;
     SITE *sp, *funnel;
@@ -1815,7 +1818,7 @@ ARTpropagate(ARTDATA *data, const char **hops, int hopcount, char **list,
         }
 
         /* Handle dontrejectfiltered. */
-        if (Filtered && sp->DropFiltered)
+        if (filtered && sp->DropFiltered)
             continue;
 
         /* Write that the site is getting it, and flag to send it. */
@@ -2576,7 +2579,7 @@ ARTpost(CHANNEL *cp)
     for (i = 0; (ngp = GroupPointers[i]) != NULL; i++)
         ngp->PostCount = 0;
 
-    token = ARTstore(cp);
+    token = ARTstore(cp, Filtered);
     /* Change trailing '\r\n' to '\0\n' of all system header fields. */
     for (i = 0; i < MAX_ARTHEADER; i++) {
         if (HDR_FOUND(i)) {
