@@ -161,7 +161,7 @@ CCcurrmode(void)
     /* Server's mode. */
     switch (Mode) {
     default:
-        snprintf(buff, sizeof(buff), "Unknown %d", Mode);
+        snprintf(buff, sizeof(buff), "Unknown %u", Mode);
         return buff;
     case OMrunning:
         return "running";
@@ -187,7 +187,7 @@ CCsdnotify(void)
     /* Server's mode. */
     switch (Mode) {
     default:
-        buffer_append_sprintf(&CCreply, "Unknown %d", Mode);
+        buffer_append_sprintf(&CCreply, "Unknown %u", Mode);
         break;
     case OMrunning:
         buffer_append_sprintf(&CCreply, "running");
@@ -302,13 +302,13 @@ CCaddhist(char *av[])
         InndHisClose();
     if (strspn(av[1], DIGITS) != strlen(av[1]))
         return "1 Bad arrival date";
-    Data.Arrived = atol(av[1]);
+    Data.Arrived = atoll(av[1]);
     if (strspn(av[2], DIGITS) != strlen(av[2]))
         return "1 Bad expiration date";
-    Data.Expires = atol(av[2]);
+    Data.Expires = atoll(av[2]);
     if (strspn(av[3], DIGITS) != strlen(av[3]))
         return "1 Bad posted date";
-    Data.Posted = atol(av[3]);
+    Data.Posted = atoll(av[3]);
 
     /* Allow empty tokens, but not badly formatted tokens. */
     if (*av[4] != '\0' && !IsToken(av[4]))
@@ -884,7 +884,7 @@ CCmode(char *unused[] UNUSED)
     /* Server's mode. */
     switch (Mode) {
     default:
-        buffer_append_sprintf(&CCreply, "Unknown %d\n", Mode);
+        buffer_append_sprintf(&CCreply, "Unknown %u\n", Mode);
         break;
     case OMrunning:
         buffer_append_sprintf(&CCreply, "running\n");
@@ -906,11 +906,11 @@ CCmode(char *unused[] UNUSED)
         count++;
     buffer_append_sprintf(&CCreply,
                           "Parameters c %lu i %lu (%d) l %lu o %d"
-                          " t %ld H %d T %d X %ld %s %s\n",
+                          " t %lu H %d T %d X %lu %s %s\n",
                           innconf->artcutoff, innconf->maxconnections, count,
                           innconf->maxartsize, MaxOutgoing,
-                          (long) TimeOut.tv_sec, RemoteLimit, RemoteTotal,
-                          (long) RemoteTimer,
+                          (unsigned long) TimeOut.tv_sec, RemoteLimit,
+                          RemoteTotal, (unsigned long) RemoteTimer,
                           innconf->xrefslave ? "slave" : "normal",
                           AnyIncoming ? "any" : "specified");
 
@@ -1027,9 +1027,9 @@ CCnameWriteInfo(struct buffer *buffer, CHANNEL *cp)
         break;
     case CTnntp:
         mode = (cp->MaxCnx > 0 && cp->ActiveCnx == 0) ? "paused" : "";
-        buffer_append_sprintf(buffer, ":%s:%ld:%s",
-                              cp->State == CScancel ? "cancel" : "nntp",
-                              (long) (Now.tv_sec - cp->LastActive), mode);
+        buffer_append_sprintf(
+            buffer, ":%s:%lu:%s", cp->State == CScancel ? "cancel" : "nntp",
+            (unsigned long) (Now.tv_sec - cp->LastActive), mode);
         break;
     case CTlocalconn:
         buffer_append_sprintf(buffer, ":localconn::");
@@ -1115,7 +1115,7 @@ CCnewgroup(char *av[])
         syslog(L_ERROR, "%s cant open %s %m", LogName, TIMES);
         IOError(WHEN, oerrno);
     } else {
-        xasprintf(&buff, "%s %ld %s\n", Name, (long) Now.tv_sec, who);
+        xasprintf(&buff, "%s %lu %s\n", Name, (unsigned long) Now.tv_sec, who);
         if (xwrite(fd, buff, strlen(buff)) < 0) {
             oerrno = errno;
             syslog(L_ERROR, "%s cant write %s %m", LogName, TIMES);
@@ -1202,8 +1202,9 @@ CCparam(char *av[])
         syslog(L_NOTICE, "%s changed -o %d", LogName, MaxOutgoing);
         break;
     case 't':
-        TimeOut.tv_sec = atol(p);
-        syslog(L_NOTICE, "%s changed -t %ld", LogName, (long) TimeOut.tv_sec);
+        TimeOut.tv_sec = atoll(p);
+        syslog(L_NOTICE, "%s changed -t %lu", LogName,
+               (unsigned long) TimeOut.tv_sec);
         break;
     case 'H':
         RemoteLimit = atoi(p);
@@ -1221,8 +1222,9 @@ CCparam(char *av[])
         RemoteTotal = temp;
         break;
     case 'X':
-        RemoteTimer = (time_t) atoi(p);
-        syslog(L_NOTICE, "%s changed -X %d", LogName, (int) RemoteTimer);
+        RemoteTimer = (time_t) atoll(p);
+        syslog(L_NOTICE, "%s changed -X %lu", LogName,
+               (unsigned long) RemoteTimer);
         break;
     }
     return NULL;
@@ -1381,18 +1383,18 @@ CCxexec(char *av[])
 
     /* Restore the systemd variables which were backed up in RCsetup()
        if socket activation was set. */
-    s = getenv("INN_BACKUP_LISTEN_FDS");
+    s = getenv(INN_ENV_LISTEN_FDS_BACKUP);
     if (s != NULL) {
-        if (setenv("LISTEN_FDS", s, true) != 0)
+        if (setenv(INN_ENV_LISTEN_FDS, s, true) != 0)
             die("setenv failed for LISTEN_FDS");
-        if (unsetenv("INN_BACKUP_LISTEN_FDS") != 0)
+        if (unsetenv(INN_ENV_LISTEN_FDS_BACKUP) != 0)
             die("unsetenv failed for INN_BACKUP_LISTEN_FDS");
     }
-    s = getenv("INN_BACKUP_LISTEN_PID");
+    s = getenv(INN_ENV_LISTEN_PID_BACKUP);
     if (s != NULL) {
-        if (setenv("LISTEN_PID", s, true) != 0)
+        if (setenv(INN_ENV_LISTEN_PID, s, true) != 0)
             die("setenv failed for LISTEN_PID");
-        if (unsetenv("INN_BACKUP_LISTEN_PID") != 0)
+        if (unsetenv(INN_ENV_LISTEN_PID_BACKUP) != 0)
             die("unsetenv failed for INN_BACKUP_LISTEN_PID");
     }
 
@@ -1400,7 +1402,7 @@ CCxexec(char *av[])
        This is needed because we need to pass them to the new innd process
        and sd_listen_fds(), which was called in RCsetup(), set it on all
        passed file descriptors. */
-    s = getenv("INN_SD_LISTEN_FDS_COUNT");
+    s = getenv(INN_ENV_LISTEN_FDS_COUNT);
     if (s == NULL)
         count = 0;
     else
@@ -1864,7 +1866,8 @@ CCtrace(char *av[])
     case '7':
     case '8':
     case '9':
-        if ((cp = CHANfromdescriptor(atoi(p))) == NULL)
+        cp = CHANfromdescriptor(atoi(p));
+        if (cp == NULL || cp->Type == CTfree)
             return CCnochannel;
         CHANtracing(cp, Flag);
         break;
