@@ -9,8 +9,8 @@
 **  2GB).
 */
 
-#include "config.h"
-#include "clibrary.h"
+#include "portable/system.h"
+
 #include <errno.h>
 
 #if HAVE_LARGE_FPOS_T
