@@ -5,6 +5,9 @@
 **
 **  Written by Ilya Etingof <ilya@glas.net>, 1999.
 **
+**  Various bug fixes, code and documentation improvements since then
+**  in 2000, 2002-2006, 2008-2011, 2013, 2015, 2017, 2018, 2020-2022, 2024.
+**
 **  This code bases on Python work for innd filtering done by
 **  G.J. Andruk <meowing@banet.net>.  Also it borrows some ideas from
 **  TCL/Perl work done by Bob Heiney and Christophe Wolfhugel.
@@ -32,9 +35,7 @@
  *  and before any standard headers are included (because Python may
  *  define some pre-processor definitions which affect the standard
  *  headers on some systems). */
-#    pragma GCC diagnostic ignored "-Wredundant-decls"
 #    include "Python.h"
-#    pragma GCC diagnostic warning "-Wredundant-decls"
 
 /*  Define Py_ssize_t when it does not exist (Python < 2.5.0). */
 #    if PY_VERSION_HEX < 0x02050000
@@ -697,7 +698,7 @@ PY_load_python(void)
         ** does it; one can also append innconf->pathfilter to sys.path once
         ** Python has been initialized.
         */
-        setenv("PYTHONPATH", innconf->pathfilter, 1);
+        setenv(INN_ENV_PYTHONPATH, innconf->pathfilter, 1);
 
         /* Build a module interface to certain nnrpd functions. */
         PyImport_AppendInittab("nnrpd", &PyInit_nnrpd);
