@@ -4,6 +4,9 @@
 **
 **  Author: Kenichi Okada <okada@opaopa.org>
 **  Created: 2000-02-22
+**
+**  Various bug fixes, code and documentation improvements since then
+**  in 2001-2004, 2006, 2008, 2009, 2011, 2013-2019, 2021-2024.
 */
 
 #include "portable/system.h"
@@ -207,7 +210,7 @@ tmp_dh_cb(SSL *s UNUSED, int export UNUSED, int keylength UNUSED)
     /* Security levels have been introduced in OpenSSL 1.1.0 and
      * LibreSSL 3.6.0.
      * Well, as this part of code is no longer active for these versions,
-     * only keep it for possible future re-use. */
+     * only keep it for possible future reuse. */
 #        if OPENSSL_VERSION_NUMBER >= 0x010100000L \
             || (defined(LIBRESSL_VERSION_NUMBER)   \
                 && LIBRESSL_VERSION_NUMBER > 0x030600000L)
@@ -336,7 +339,7 @@ tls_dump(const char *s, int len)
         buf[0] = '\0'; /* Start with empty string. */
         ss = buf;
 
-        snprintf(ss, sizeof(buf), "%04x ", i * DUMP_WIDTH);
+        snprintf(ss, sizeof(buf), "%04x ", (unsigned int) (i * DUMP_WIDTH));
         ss += strlen(ss);
         for (j = 0; j < DUMP_WIDTH; j++) {
             if (((i * DUMP_WIDTH) + j) >= len) {
@@ -870,7 +873,7 @@ bio_dump_cb(BIO *bio, int cmd, const char *argp, size_t len, int argi UNUSED,
 
 /*
 **  This is the actual startup routine for the connection.  We expect
-**  that the buffers are flushed and the "382 Continue with TLS negociation"
+**  that the buffers are flushed and the "382 Continue with TLS negotiation"
 **  was sent to the client (if using STARTTLS), so that we can immediately
 **  start the TLS handshake process.
 **
