@@ -3,6 +3,9 @@
 **
 **  Original implementation written by Bo Lindbergh (2020-12-17).
 **  <2bfjdsla52kztwejndzdstsxl9athp@gmail.com>
+**
+**  Various bug fixes, code and documentation improvements since then
+**  in 2021-2024.
 */
 
 #include "config.h"
@@ -814,14 +817,12 @@ sql_error_response(client_t *client, int status)
 
 #    define fail_stmt() goto failure_stmt
 
-#    define failure_response           \
-    failure:                           \
-        simple_response(client, code); \
+#    define failure_response                     \
+        failure : simple_response(client, code); \
         break
 
-#    define failure_stmt_response           \
-    failure_stmt:                           \
-        sql_error_response(client, status); \
+#    define failure_stmt_response                          \
+        failure_stmt : sql_error_response(client, status); \
         break
 
 #    define failhandling      \
